@@ -12,13 +12,11 @@ available from its original location tespy/networks/network_reader.py
 
 SPDX-License-Identifier: MIT
 """
-
 import ast
 import json
 import logging
 import os
 
-import numpy as np
 import pandas as pd
 
 from tespy.components import CombustionChamber
@@ -133,13 +131,14 @@ def load_network(path):
     The imported network has the following additional features:
 
     - Connections are accessible by label, e.g.
-      :code:`myimportednetwork.connections['myconnection']`. The default label
+      :code:`myimportednetwork.get_conn('myconnection')`. The default label
       logic is :code:`source:source_id_target:target_id`, where the source
       means the label of the component the connection originates from and
       target means the label of the component, the connections targets on.
     - Components are accessible by label as well, e.g. for a component
-      'heat exchanger' :code:`myimportednetwork.components['heat exchanger']`.
-    - Busses are accessible by label, too, e.g. for a bus 'power input'
+      'heat exchanger' :code:`myimportednetwork.get_comp('heat exchanger')`.
+    - Busses are stored in a dict like structure, therefore accessible like
+      follows, e.g. a bus labeld 'power input'
       :code:`myimportednetwork.busses['power input']`.
 
     Example
@@ -213,7 +212,7 @@ def load_network(path):
     >>> nw.lin_dep
     False
     >>> nw.save('exported_nwk')
-    >>> mass_flow = round(nw.connections['ambient air'].m.val_SI, 1)
+    >>> mass_flow = round(nw.get_conn('ambient air').m.val_SI, 1)
     >>> c.set_attr(igva='var')
     >>> nw.solve('offdesign', design_path='exported_nwk')
     >>> round(t.eta_s.val, 1)
@@ -238,19 +237,19 @@ def load_network(path):
     >>> imported_nwk.solve('design', init_path='exported_nwk')
     >>> imported_nwk.lin_dep
     False
-    >>> round(imported_nwk.connections['ambient air'].m.val_SI, 1) == mass_flow
+    >>> round(imported_nwk.get_conn('ambient air').m.val_SI, 1) == mass_flow
     True
-    >>> round(imported_nwk.components['turbine'].eta_s.val, 3)
+    >>> round(imported_nwk.get_comp('turbine').eta_s.val, 3)
     0.9
-    >>> imported_nwk.components['compressor'].set_attr(igva='var')
+    >>> imported_nwk.get_comp('compressor').set_attr(igva='var')
     >>> imported_nwk.solve('offdesign', design_path='exported_nwk')
-    >>> round(imported_nwk.components['turbine'].eta_s.val, 3)
+    >>> round(imported_nwk.get_comp('turbine').eta_s.val, 3)
     0.9
     >>> imported_nwk.busses['total power output'].set_attr(P=-0.75e6)
     >>> imported_nwk.solve('offdesign', design_path='exported_nwk')
-    >>> round(imported_nwk.components['turbine'].eta_s.val, 3) == eta_s_t
+    >>> round(imported_nwk.get_comp('turbine').eta_s.val, 3) == eta_s_t
     True
-    >>> round(imported_nwk.components['compressor'].igva.val, 3) == igva
+    >>> round(imported_nwk.get_comp('compressor').igva.val, 3) == igva
     True
     >>> shutil.rmtree('./exported_nwk', ignore_errors=True)
     """
@@ -273,7 +272,8 @@ def load_network(path):
         logging.debug(msg)
 
     except FileNotFoundError:
-        char_lines = pd.DataFrame(columns=['id', 'type', 'x', 'y'])
+        char_lines = pd.DataFrame(
+            columns=['id', 'type', 'x', 'y'], dtype='object')
 
     # load characteristic maps
     fn = path_comps + 'char_map.csv'
@@ -286,10 +286,11 @@ def load_network(path):
                                             'z': ast.literal_eval})
 
     except FileNotFoundError:
-        char_maps = pd.DataFrame(columns=['id', 'type', 'x', 'y', 'z'])
+        char_maps = pd.DataFrame(
+            columns=['id', 'type', 'x', 'y', 'z'], dtype='object')
 
     # load components
-    comps = pd.DataFrame()
+    comps = pd.DataFrame(dtype='object')
 
     files = os.listdir(path_comps)
     for f in files:
@@ -353,7 +354,7 @@ def load_network(path):
         logging.debug(msg)
 
     except FileNotFoundError:
-        busses = pd.DataFrame()
+        busses = pd.DataFrame(dtype='object')
         msg = 'No bus data found!'
         logging.debug(msg)
 
@@ -410,10 +411,9 @@ def construct_comps(c, *args):
     for key in ['design', 'offdesign', 'design_path', 'local_design',
                 'local_offdesign']:
         if key in c:
-            try:
-                if np.isnan(c[key]):
-                    kwargs[key] = None
-            except TypeError:
+            if isinstance(c[key], float):
+                kwargs[key] = None
+            else:
                 kwargs[key] = c[key]
 
     for key, value in instance.variables.items():
@@ -546,10 +546,9 @@ def construct_conns(c, *args):
     for key in ['design', 'offdesign', 'design_path', 'local_design',
                 'local_offdesign', 'label']:
         if key in c:
-            try:
-                if np.isnan(c[key]):
-                    setattr(conn, key, None)
-            except TypeError:
+            if isinstance(c[key], float):
+                setattr(conn, key, None)
+            else:
                 setattr(conn, key, c[key])
 
     # read fluid properties
