@@ -8,9 +8,9 @@ available from its original location tespy/tools/document_models.py
 
 SPDX-License-Identifier: MIT
 """
-import collections
 import os
 import sys
+from collections.abc import Mapping
 from copy import deepcopy
 from datetime import date
 
@@ -85,7 +85,7 @@ def merge_dicts(dict1, dict2):
     result = deepcopy(dict1)
 
     for key, value in dict2.items():
-        if isinstance(value, collections.Mapping):
+        if isinstance(value, Mapping):
             result[key] = merge_dicts(result.get(key, {}), value)
         else:
             result[key] = deepcopy(dict2[key])
@@ -740,7 +740,7 @@ def get_component_specifications(nw, cp, rpt):
 
     # # get parameter groups tables
     for param, data in data_dict_gcp.items():
-        df_data_gcp = pd.DataFrame(data)
+        df_data_gcp = pd.DataFrame(data, dtype='object')
         if df_data_gcp.size > 0:
             for col in df_data_gcp.columns:
                 col_headers[col] = col.replace('_', r'\_')
@@ -796,7 +796,8 @@ def document_busses(nw, rpt):
                 df.loc['total', 'bus value'] = (
                     fmt.format(df.loc['total', 'bus value']))
         else:
-            df = pd.DataFrame(columns=['comp eq', 'bus eq', 'eta ref'])
+            df = pd.DataFrame(
+                columns=['comp eq', 'bus eq', 'eta ref'], dtype='object')
 
         figures = []
         for cp in b.comps.index:
@@ -925,7 +926,7 @@ def data_to_df(data):
         Polished DataFrame.
     """
     if not isinstance(data, pd.DataFrame):
-        df = pd.DataFrame(data)
+        df = pd.DataFrame(data, dtype='object')
     else:
         df = data
     to_drop = [n for n in df.columns if n != 'label']
