@@ -13,20 +13,18 @@ import shutil
 
 import numpy as np
 
-from tespy.components.basics import sink
-from tespy.components.basics import source
-from tespy.components.turbomachinery import compressor
-from tespy.components.turbomachinery import pump
-from tespy.components.turbomachinery import turbine
-from tespy.components.turbomachinery import turbomachine
-from tespy.connections import connection
-from tespy.connections import ref
-from tespy.networks.networks import network
-from tespy.tools.characteristics import char_line
-from tespy.tools.characteristics import compressor_map
+from tespy.components import Compressor
+from tespy.components import Pump
+from tespy.components import Sink
+from tespy.components import Source
+from tespy.components import Turbine
+from tespy.components.turbomachinery.turbomachine import Turbomachine
+from tespy.connections import Connection
+from tespy.networks import Network
+from tespy.tools.characteristics import CharLine
+from tespy.tools.characteristics import CharMap
 from tespy.tools.characteristics import load_default_char as ldc
-from tespy.tools.data_containers import dc_cc
-from tespy.tools.data_containers import dc_cm
+from tespy.tools.fluid_properties import isentropic
 from tespy.tools.fluid_properties import s_mix_ph
 
 
@@ -39,17 +37,17 @@ def convergence_check(lin_dep):
 class TestTurbomachinery:
 
     def setup_network(self, instance):
-        self.nw = network(['INCOMP::DowQ', 'NH3', 'N2', 'O2', 'Ar'],
+        self.nw = Network(['INCOMP::DowQ', 'NH3', 'N2', 'O2', 'Ar'],
                           T_unit='C', p_unit='bar', v_unit='m3 / s')
-        self.source = source('source')
-        self.sink = sink('sink')
-        self.c1 = connection(self.source, 'out1', instance, 'in1')
-        self.c2 = connection(instance, 'out1', self.sink, 'in1')
+        self.source = Source('source')
+        self.sink = Sink('sink')
+        self.c1 = Connection(self.source, 'out1', instance, 'in1')
+        self.c2 = Connection(instance, 'out1', self.sink, 'in1')
         self.nw.add_conns(self.c1, self.c2)
 
-    def test_compressor(self):
+    def test_Compressor(self):
         """Test component properties of compressors."""
-        instance = compressor('compressor')
+        instance = Compressor('compressor')
         self.setup_network(instance)
 
         # compress NH3, other fluids in network are for turbine, pump, ...
@@ -62,8 +60,9 @@ class TestTurbomachinery:
         self.nw.save('tmp')
 
         # test isentropic efficiency value
-        eta_s_d = ((instance.h_os('') - self.c1.h.val_SI) /
-                   (self.c2.h.val_SI - self.c1.h.val_SI))
+        eta_s_d = (
+            (isentropic(self.c1.get_flow(), self.c2.get_flow()) -
+             self.c1.h.val_SI) / (self.c2.h.val_SI - self.c1.h.val_SI))
         msg = ('Value of isentropic efficiency must be ' + str(eta_s_d) +
                ', is ' + str(instance.eta_s.val) + '.')
         assert round(eta_s_d, 3) == round(instance.eta_s.val, 3), msg
@@ -74,8 +73,9 @@ class TestTurbomachinery:
         convergence_check(self.nw.lin_dep)
 
         # test calculated value
-        eta_s = ((instance.h_os('') - self.c1.h.val_SI) /
-                 (self.c2.h.val_SI - self.c1.h.val_SI))
+        eta_s = (
+            (isentropic(self.c1.get_flow(), self.c2.get_flow()) -
+             self.c1.h.val_SI) / (self.c2.h.val_SI - self.c1.h.val_SI))
         msg = ('Value of isentropic efficiency must be ' + str(eta_s) +
                ', is ' + str(instance.eta_s.val) + '.')
         assert round(eta_s, 3) == round(instance.eta_s.val, 3), msg
@@ -83,9 +83,14 @@ class TestTurbomachinery:
         # remove pressure at outlet, use characteristic map for pressure
         # rise calculation
         self.c2.set_attr(p=np.nan)
-        instance.set_attr(char_map=dc_cm(func=ldc(
-            'compressor', 'char_map', 'DEFAULT', compressor_map),
-            is_set=True), eta_s=np.nan)
+        instance.set_attr(
+            char_map_pr={'char_func': ldc(
+                'compressor', 'char_map_pr', 'DEFAULT', CharMap),
+                'is_set': True},
+            char_map_eta_s={'char_func': ldc(
+                'compressor', 'char_map_eta_s', 'DEFAULT', CharMap),
+                'is_set': True},
+            eta_s=np.nan, igva=0)
 
         # offdesign test, efficiency value should be at design value
         self.nw.solve('offdesign', design_path='tmp')
@@ -101,7 +106,7 @@ class TestTurbomachinery:
         convergence_check(self.nw.lin_dep)
 
         # should be value
-        eta_s = eta_s_d * instance.char_map.func.z2[6, 0]
+        eta_s = eta_s_d * instance.char_map_eta_s.char_func.z[6, 0]
         msg = ('Value of isentropic efficiency (' + str(instance.eta_s.val) +
                ') must be at (' + str(round(eta_s, 4)) + ').')
         assert round(eta_s, 4) == round(instance.eta_s.val, 4), msg
@@ -112,7 +117,7 @@ class TestTurbomachinery:
         self.nw.solve('offdesign', design_path='tmp', init_path='tmp')
         convergence_check(self.nw.lin_dep)
         # should be value
-        eta_s = eta_s_d * instance.char_map.func.z2[0, 9]
+        eta_s = eta_s_d * instance.char_map_eta_s.char_func.z[0, 9]
         msg = ('Value of isentropic efficiency (' + str(instance.eta_s.val) +
                ') must be at (' + str(round(eta_s, 4)) + ').')
         assert round(eta_s, 4) == round(instance.eta_s.val, 4), msg
@@ -122,10 +127,11 @@ class TestTurbomachinery:
         self.c1.set_attr(v=1, T=5, m=np.nan)
 
         # test parameter specification for eta_s_char with unset char map
-        instance.set_attr(eta_s_char=dc_cc(func=ldc(
-            'compressor', 'eta_s_char', 'DEFAULT', char_line),
-            is_set=True, param='m'))
-        instance.char_map.is_set = False
+        instance.set_attr(eta_s_char={'char_func': ldc(
+            'compressor', 'eta_s_char', 'DEFAULT', CharLine),
+            'is_set': True, 'param': 'm'})
+        instance.char_map_eta_s.is_set = False
+        instance.char_map_pr.is_set = False
         self.nw.solve('offdesign', design_path='tmp')
         convergence_check(self.nw.lin_dep)
         msg = ('Value of isentropic efficiency must be ' + str(eta_s_d) +
@@ -136,7 +142,7 @@ class TestTurbomachinery:
         self.c1.set_attr(v=1.5)
         self.nw.solve('offdesign', design_path='tmp')
         convergence_check(self.nw.lin_dep)
-        eta_s = round(eta_s_d * instance.eta_s_char.func.evaluate(
+        eta_s = round(eta_s_d * instance.eta_s_char.char_func.evaluate(
             self.c1.m.val_SI / self.c1.m.design), 3)
         msg = ('Value of isentropic efficiency must be ' + str(eta_s) +
                ', is ' + str(round(instance.eta_s.val, 3)) + '.')
@@ -150,16 +156,16 @@ class TestTurbomachinery:
         convergence_check(self.nw.lin_dep)
         expr = (self.c2.p.val_SI * self.c1.p.design /
                 (self.c2.p.design * self.c1.p.val_SI))
-        eta_s = round(eta_s_d * instance.eta_s_char.func.evaluate(expr), 3)
+        eta_s = round(
+            eta_s_d * instance.eta_s_char.char_func.evaluate(expr), 3)
         msg = ('Value of isentropic efficiency must be ' + str(eta_s) +
                ', is ' + str(round(instance.eta_s.val, 3)) + '.')
         assert eta_s == round(instance.eta_s.val, 3), msg
-
         shutil.rmtree('./tmp', ignore_errors=True)
 
-    def test_pump(self):
+    def test_Pump(self):
         """Test component properties of pumps."""
-        instance = pump('pump')
+        instance = Pump('pump')
         self.setup_network(instance)
         fl = {'N2': 0, 'O2': 0, 'Ar': 0, 'DowQ': 1, 'NH3': 0}
         self.c1.set_attr(fluid=fl, v=1, p=5, T=50)
@@ -169,16 +175,17 @@ class TestTurbomachinery:
         convergence_check(self.nw.lin_dep)
 
         # test calculated value for efficiency
-        eta_s = ((instance.h_os('') - self.c1.h.val_SI) /
-                 (self.c2.h.val_SI - self.c1.h.val_SI))
+        eta_s = (
+            (isentropic(self.c1.get_flow(), self.c2.get_flow()) -
+             self.c1.h.val_SI) / (self.c2.h.val_SI - self.c1.h.val_SI))
         msg = ('Value of isentropic efficiency must be ' + str(eta_s) +
                ', is ' + str(instance.eta_s.val) + '.')
         assert eta_s == instance.eta_s.val, msg
 
         # isentropic efficiency of 1 means inlet and outlet entropy are
         # identical
-        s1 = round(s_mix_ph(self.c1.to_flow()), 4)
-        s2 = round(s_mix_ph(self.c2.to_flow()), 4)
+        s1 = round(s_mix_ph(self.c1.get_flow()), 4)
+        s2 = round(s_mix_ph(self.c2.get_flow()), 4)
         msg = ('Value of entropy must be identical for inlet (' + str(s1) +
                ') and outlet (' + str(s2) +
                ') at 100 % isentropic efficiency.')
@@ -196,12 +203,12 @@ class TestTurbomachinery:
         # flow char (pressure rise vs. volumetric flow)
         x = [0, 0.2, 0.4, 0.6, 0.8, 1, 1.2, 1.4]
         y = np.array([14, 13.5, 12.5, 11, 9, 6.5, 3.5, 0]) * 1e5
-        char = dc_cc(func=char_line(x, y), is_set=True)
+        char = {'char_func': CharLine(x, y), 'is_set': True}
         # apply flow char and eta_s char
-        instance.set_attr(flow_char=char, eta_s=np.nan,
-                          eta_s_char=dc_cc(func=ldc('pump', 'eta_s_char',
-                                                    'DEFAULT', char_line),
-                                           is_set=True))
+        instance.set_attr(
+            flow_char=char, eta_s=np.nan, eta_s_char={
+                'char_func': ldc('pump', 'eta_s_char', 'DEFAULT', CharLine),
+                'is_set': True})
         self.nw.solve('offdesign', design_path='tmp')
         convergence_check(self.nw.lin_dep)
 
@@ -221,7 +228,7 @@ class TestTurbomachinery:
         assert round(self.c2.p.val_SI - self.c1.p.val_SI, 0) == dp, msg
 
         # test value of isentropic efficiency
-        eta_s = round(eta_s_d * instance.eta_s_char.func.evaluate(
+        eta_s = round(eta_s_d * instance.eta_s_char.char_func.evaluate(
             self.c1.v.val_SI / self.c1.v.design), 3)
         msg = ('Value of isentropic efficiency must be ' + str(eta_s) +
                ', is ' + str(instance.eta_s.val) + '.')
@@ -230,8 +237,8 @@ class TestTurbomachinery:
 
         # test boundaries of characteristic line:
         # lower boundary
-        self.c2.set_attr(T=ref(self.c1, 0, 20))
-        self.c1.set_attr(v=-0.1)
+        instance.set_attr(eta_s=0.8)
+        self.c1.set_attr(m=0, v=None)
         self.nw.solve('design')
         convergence_check(self.nw.lin_dep)
         msg = ('Value of power must be ' + str(14e5) + ', is ' +
@@ -239,7 +246,7 @@ class TestTurbomachinery:
         assert round(self.c2.p.val_SI - self.c1.p.val_SI, 0) == 14e5, msg
 
         # upper boundary
-        self.c1.set_attr(v=1.5)
+        self.c1.set_attr(v=1.5, m=None)
         self.nw.solve('design')
         convergence_check(self.nw.lin_dep)
         msg = ('Value of power must be 0, is ' +
@@ -247,9 +254,9 @@ class TestTurbomachinery:
         assert round(self.c2.p.val_SI - self.c1.p.val_SI, 0) == 0, msg
         shutil.rmtree('./tmp', ignore_errors=True)
 
-    def test_turbine(self):
+    def test_Turbine(self):
         """Test component properties of turbines."""
-        instance = turbine('turbine')
+        instance = Turbine('turbine')
         self.setup_network(instance)
         fl = {'N2': 0.7556, 'O2': 0.2315, 'Ar': 0.0129, 'DowQ': 0,
               'NH3': 0}
@@ -261,8 +268,10 @@ class TestTurbomachinery:
         self.nw.save('tmp')
 
         # design value of isentropic efficiency
-        eta_s_d = ((self.c2.h.val_SI - self.c1.h.val_SI) /
-                   (instance.h_os('') - self.c1.h.val_SI))
+        eta_s_d = (
+            (self.c2.h.val_SI - self.c1.h.val_SI) / (
+                isentropic(self.c1.get_flow(), self.c2.get_flow()) -
+                self.c1.h.val_SI))
         msg = ('Value of isentropic efficiency must be ' +
                str(round(eta_s_d, 3)) + ', is ' + str(instance.eta_s.val) +
                '.')
@@ -272,11 +281,13 @@ class TestTurbomachinery:
         instance.set_attr(eta_s=1.1)
         self.nw.solve('design')
         convergence_check(self.nw.lin_dep)
-        eta_s = round((self.c2.h.val_SI - self.c1.h.val_SI) /
-                      (instance.h_os('') - self.c1.h.val_SI), 3)
+        eta_s = (
+            (self.c2.h.val_SI - self.c1.h.val_SI) / (
+                isentropic(self.c1.get_flow(), self.c2.get_flow()) -
+                self.c1.h.val_SI))
         msg = ('Value of isentropic efficiency must be ' + str(eta_s) +
                ', is ' + str(instance.eta_s.val) + '.')
-        assert eta_s == round(instance.eta_s.val, 3), msg
+        assert round(eta_s, 3) == round(instance.eta_s.val, 3), msg
 
         # unset isentropic efficiency and inlet pressure,
         # use characteristcs and cone law instead, parameters have to be in
@@ -312,7 +323,7 @@ class TestTurbomachinery:
         self.nw.solve('offdesign', design_path='tmp')
         convergence_check(self.nw.lin_dep)
         expr = self.c1.v.val_SI / self.c1.v.design
-        eta_s = round(eta_s_d * instance.eta_s_char.func.evaluate(expr), 3)
+        eta_s = round(eta_s_d * instance.eta_s_char.char_func.evaluate(expr), 3)
         msg = ('Value of isentropic efficiency (' +
                str(round(instance.eta_s.val, 3)) +
                ') must be (' + str(eta_s) + ').')
@@ -324,33 +335,21 @@ class TestTurbomachinery:
         convergence_check(self.nw.lin_dep)
         expr = (self.c2.p.val_SI * self.c1.p.design /
                 (self.c2.p.design * self.c1.p.val_SI))
-        eta_s = round(eta_s_d * instance.eta_s_char.func.evaluate(expr), 3)
-        msg = ('Value of isentropic efficiency (' +
-               str(round(instance.eta_s.val, 3)) +
-               ') must be (' + str(eta_s) + ').')
-        assert eta_s == round(instance.eta_s.val, 3), msg
-
-        # test parameter specification dh_s
-        instance.eta_s_char.param = 'dh_s'
-        self.nw.solve('offdesign', design_path='tmp')
-        convergence_check(self.nw.lin_dep)
-        expr = (instance.h_os('') - self.c1.h.val_SI) / instance.dh_s_ref
-        eta_s = round(eta_s_d * instance.eta_s_char.func.evaluate(expr), 3)
+        eta_s = round(eta_s_d * instance.eta_s_char.char_func.evaluate(expr), 3)
         msg = ('Value of isentropic efficiency (' +
                str(round(instance.eta_s.val, 3)) +
                ') must be (' + str(eta_s) + ').')
         assert eta_s == round(instance.eta_s.val, 3), msg
         shutil.rmtree('./tmp', ignore_errors=True)
 
-    def test_turbomachine(self):
+    def test_Turbomachine(self):
         """Test component properties of turbomachines."""
-        instance = turbomachine('turbomachine')
+        instance = Turbomachine('turbomachine')
         msg = ('Component name must be turbomachine, is ' +
                instance.component() + '.')
         assert 'turbomachine' == instance.component(), msg
         self.setup_network(instance)
-        fl = {'N2': 0.7556, 'O2': 0.2315, 'Ar': 0.0129, 'DowQ': 0,
-              'H2O': 0, 'NH3': 0, 'CO2': 0, 'CH4': 0}
+        fl = {'N2': 0.7556, 'O2': 0.2315, 'Ar': 0.0129, 'DowQ': 0, 'NH3': 0}
         self.c1.set_attr(fluid=fl, m=10, p=1, h=1e5)
         self.c2.set_attr(p=3, h=2e5)
 
